<?php
/**
 * @package     Joomla.Platform
 * @subpackage  Document
 *
 * @copyright   Copyright (C) 2005 - 2012 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */

defined('JPATH_PLATFORM') or die;

/**
 * JDocument Module renderer
 *
 * @package     Joomla.Platform
 * @subpackage  Document
 * @since       11.1
 */
class JDocumentRendererModule extends JDocumentRenderer
{
	/**
	 * Renders a module script and returns the results as a string
	 *
	 * @param   string  $module   The name of the module to render
	 * @param   array   $attribs  Associative array of values
	 * @param   string  $content  If present, module information from the buffer will be used
	 *
	 * @return  string  The output of the script
	 *
	 * @since   11.1
	 */
	public function render($module, $attribs = array(), $content = null)
	{
		if (!is_object($module))
		{
			$title = isset($attribs['title']) ? $attribs['title'] : null;

			$module = JModuleHelper::getModule($module, $title);

			if (!is_object($module))
			{
				if (is_null($content))
				{
					return '';
				}
				else
				{
					/**
					 * If module isn't found in the database but data has been pushed in the buffer
					 * we want to render it
					 */
					$tmp = $module;
					$module = new stdClass;
					$module->params = null;
					$module->module = $tmp;
					$module->id = 0;
					$module->user = 0;
				}
			}
		}

		// Get the user and configuration object
		// $user = JFactory::getUser();
		$conf = JFactory::getConfig();

		// Set the module content
		if (!is_null($content))
		{
			$module->content = $content;
		}

		// Get module parameters
		$params = new JRegistry;
		$params->loadString($module->params);

		// Use parameters from template
		if (isset($attribs['params']))
		{
			$template_params = new JRegistry;
			$template_params->loadString(html_entity_decode($attribs['params'], ENT_COMPAT, 'UTF-8'));
			$params->merge($template_params);
			$module = clone $module;
			$module->params = (string) $params;
		}

		$contents = '';

		// Default for compatibility purposes. Set cachemode parameter or use JModuleHelper::moduleCache from within the
		// module instead
		$cachemode = $params->get('cachemode', 'oldstatic');

		if ($params->get('cache', 0) == 1 && $conf->get('caching') >= 1 && $cachemode != 'id' && $cachemode != 'safeuri')
		{

			// Default to itemid creating method and workarounds on
			$cacheparams = new stdClass;
			$cacheparams->cachemode = $cachemode;
			$cacheparams->class = 'JModuleHelper';
			$cacheparams->method = 'renderModule';
			$cacheparams->methodparams = array($module, $attribs);

			$contents = JModuleHelper::ModuleCache($module, $params, $cacheparams);

		}
		else
		{
			$contents = JModuleHelper::renderModule($module, $attribs);
		}
	$plugindate = JPluginHelper::getPlugin('content', 'joominapersaiannumber');
    $pluginParamsdate = new JRegistry();
    $pluginParamsdate->loadString($plugindate->params);
    $paramdate = $pluginParamsdate->get('modulepersiannumber', '1'); 		
if($paramdate==0){		
                $contents = $this->JoominaReplace('1', '۱', $contents);
		        $contents = $this->JoominaReplace('2', '۲', $contents);
		        $contents = $this->JoominaReplace('3', '۳', $contents);
		        $contents = $this->JoominaReplace('4', '۴', $contents);
		        $contents = $this->JoominaReplace('5', '۵', $contents);
		        $contents = $this->JoominaReplace('6', '۶', $contents);
		        $contents = $this->JoominaReplace('7', '۷', $contents);
		        $contents = $this->JoominaReplace('8', '۸', $contents);
		        $contents = $this->JoominaReplace('9', '۹', $contents);
		        $contents = $this->JoominaReplace('0', '۰', $contents);
		        $contents = $this->JoominaReplace('٤', '۴', $contents);
		        $contents = $this->JoominaReplace('٥', '۵', $contents);
		        $contents = $this->JoominaReplace('٦', '۶', $contents);
		        $contents = $this->JoominaReplace('ك', 'ک', $contents);
		        $contents = $this->JoominaReplace('ی', 'ی', $contents);
}				
		return $contents;
	}
    function JoominaReplace($orginal, $persiannum, $mytext)
    {
       preg_match_all("%(?<=>)[^><]+?(?=<)%", $mytext, $match);
       if(empty($match) OR !is_array($match))
          return $mytext;
       for($i=0; $i<count($match); $i++)
           $subjectString=str_replace($orginal, $persiannum, $match[$i]);
       $tmp_count=count($match[0]);
       for($i=0; $i<$tmp_count; $i++)
           $mytext=str_replace($match[0][$i], $subjectString[$i], $mytext);
       return $mytext;
    }	
}
